@@ -26,7 +26,7 @@ sys.modules['ccxt'] = ccxt_module
 
 # ----------------------------------------------------------------------------
 
-__version__ = '4.4.72'
+__version__ = '4.4.82'
 
 # ----------------------------------------------------------------------------
 
@@ -87,10 +87,9 @@ from ccxt.base.errors import CancelPending                            # noqa: F4
 from ccxt.base.errors import UnsubscribeError                         # noqa: F401
 from ccxt.base.errors import error_hierarchy                          # noqa: F401
 
-from ccxt.bitfinex1 import bitfinex1                                  # noqa: F401
 from ccxt.gate import gate                                            # noqa: F401
 
-exchanges = [    'bitfinex1',    'gate',]
+exchanges = [    'gate',]
 
 base = [
     'Exchange',
